# NOTE: Derived from blib/lib/ClearCase/Wrapper.pm.
# Changes made here will be lost when autosplit is run again.
# See AutoSplit.pm.
package ClearCase::Wrapper;

#line 533 "blib/lib/ClearCase/Wrapper.pm (autosplit into blib/lib/auto/ClearCase/Wrapper/AutoViewPrivate.al)"
# Return the list of view-private files according to the
# -dir/-rec/-all/-avobs flags. Passes the supplied args to
# ct lsp and massages the result. The first param is a boolean
# indicating whether to give the user an "ok to proceed?"
# prompt; this function may exit if the answer is no.
sub AutoViewPrivate {
    my($ok, $do, $scope, $parents, $screen) = @_;
    my @vps;
    # Can't use lsprivate in a snapshot view ...
    if (-e '.@@/main/0') {
	my $lsp = Argv->new([$^X, '-S', $0, 'lsp'], [qw(-s -oth), $scope]);
	$lsp->opts($lsp->opts, '-do') if $do;
	chomp(@vps = $lsp->qx);
    } else {
	require File::Spec;
	File::Spec->VERSION(0.82);
	die Msg('E', "-do flag not supported in snapshot views") if $do;
	die Msg('E', "$scope flag not supported in snapshot views")
							    if $scope =~ /^-a/;
	my $ls = ClearCase::Argv->ls([qw(-s -view -vis)]);
	$ls->opts($ls->opts, $scope) if $scope =~ /^-r/;
	chomp(@vps = $ls->qx);
	@vps = map {File::Spec->rel2abs($_)} @vps;
    }
    if (MSWIN) {
	for (@vps) { s%\\%/%g }
    }
    # Some v-p files we may not be interested in ...
    @vps = grep !m%$screen%, @vps if $screen;
    @vps = sort @vps;

    if ($parents && @vps && $scope =~ /^-(dir|rec)/) {
	# In case the command was run in a v-p directory, traverse upwards
	# towards the vob root adding parent directories till we reach
	# a versioned dir.
	require Cwd;
	my $ctls = ClearCase::Argv->ls({autofail=>1}, [qw(-d -s -vob)], '.');
	while (! $ctls->qx) {
	    unshift(@vps, Cwd::getcwd());
	    $vps[0] =~ s%\\%/%g if MSWIN;
	    if (! Cwd::chdir('..')) {
		my $err = "$!";
		die Msg('E', Cwd::getcwd() . ": $err");
	    }
	}
    }

    _ShowFound($ok, @vps);	# may exit
    exit 0 unless @vps;
    return @vps;
}

# end of ClearCase::Wrapper::AutoViewPrivate
1;
