# NOTE: Derived from blib/lib/ClearCase/Wrapper.pm.
# Changes made here will be lost when autosplit is run again.
# See AutoSplit.pm.
package ClearCase::Wrapper;

#line 1092 "blib/lib/ClearCase/Wrapper.pm (autosplit into blib/lib/auto/ClearCase/Wrapper/mkelem.al)"
sub mkelem {
    my %opt;
    GetOptions(\%opt, qw(directory recurse all avobs do ok));
    die Msg('E', "-all|-avobs flags not supported for mkelem")
					if $opt{all} || $opt{avobs};
    return unless $opt{directory} || $opt{recurse};

    # Derive the list of view-private files to work on. This may exit
    # if no eligibles are found.
    my $scope = $opt{recurse} ? '-rec' : '-dir';
    my $re = q%(?:\.(?:n|mv)fs_\d+|\.(?:abe|cmake)\.state|\.(?:swp|tmp))$%;
    my @vps = AutoViewPrivate($opt{ok}, $opt{do}, $scope, 1, $re);

    my $ct = ClearCase::Argv->new({-autofail=>1});

    # We'll be separating the elements-to-be into files and directories.
    my(@files, %dirs);

    # If the parent directories of any of the candidates are already
    # versioned elements we may need to check them out.
    require File::Basename;
    my %seen;
    for (@vps) {
	my $d = File::Basename::dirname($_);
	next if ! $d || $dirs{$d};
	next if $seen{$d}++;
	my $lsd = $ct->ls(['-d'], $d)->qx;
	# If no version selector was given it's a view-private dir and
	# will be handled below.
	next unless $lsd =~ /\sRule:\s/;
	# If already checked out, nothing to do.
	next if $lsd =~ /CHECKEDOUT$/;
	# Now we know it's an element and needs to be checked out.
	$dirs{$d}++;
    }
    $ct->co(['-nc'], keys %dirs)->system if %dirs;

    # Process candidate directories here, then do files below.
    for my $cand (@vps) {
	if (! -d $cand) {
	    push(@ARGV, $cand);
	    next;
	}
	# Now we know we're dealing with directories.  These must not
	# exist at mkelem time so we move them aside, make
	# a versioned dir, then move all the files from the original
	# back into the new dir (still as view-private files).
	my $tmpdir = "$cand.$$.keep.d";
	die Msg('E', "$cand: $!") if !rename($cand, $tmpdir);
	$ct->mkdir(['-nc'], $cand)->system;
	opendir(DIR, $tmpdir) || die Msg('E', "$tmpdir: $!");
	while (defined(my $i = readdir(DIR))) {
	    next if $i eq '.' || $i eq '..';
	    die Msg('E', "$cand/$i: $!") if !rename("$tmpdir/$i", "$cand/$i");
	}
	closedir DIR;
	warn Msg('W', "$tmpdir: $!") unless rmdir $tmpdir;
	# Keep a record of directories to be checked in when done.
	$dirs{$cand}++;
    }

    # Now we've made all the directories, do the files in one fell swoop.
    $ct->argv(@ARGV)->system if grep -f, @ARGV;

    # Last - if the -ci flag was supplied, check the dirs back in.
    # Also flush the view cache if dirs were created. Really
    # we could be smarter here because it really only needs flushing
    # if one of the dirs was the cwd.
    if (%dirs) {
	$ct->ci(['-nc'], keys %dirs)->system if grep /^-ci$/, @ARGV;
	$ct->setcs(['-curr'])->system;
    }

    # Done - don't drop back to main program.
    exit $?;
}

# end of ClearCase::Wrapper::mkelem
1;
